import { Hono } from "hono";
import { Home } from "@blog/templates/Pages/Home";
import { PostMeta } from "@blog/models/PostMeta";
import { Post } from '@blog/models/Post';
import { PostService } from '@blog/services/post-file';

type Posts = {
  postService: PostService 
};

const app = new Hono<{ Variables: Posts }>();

app.get("/", async (c) => {
  const postService: PostService = c.get('postService');

  const isDev: boolean = process.env.DEPLOY_MODE == 'development';
  const posts = isDev
    ? postService.getAllPosts()
    : postService.getPublishedPosts();

  const postList: PostMeta[] = Array.from(posts).map((p: Post) => p.meta);

  return c.render(<Home posts={postList} />, {
    meta: {
      description: "The blog for Dave Smith-Hayes, a dad and developer.",
      mastodonUrl: "https://hachyderm.io/@davesh"
    },
  });
});

export default app;
